==> zrythm-0.8.757.tar.xz: zrythm-0.8.757/TRADEMARKS.md <==
Trademark Policy
================

# Applicable Trademarks
The word "Zrythm" and the Zrythm logo are trademarks
of Alexandros Theodotou pending registration.

# Objective of this Policy
The objective of this trademark policy is:
- to encourage widespread use and adoption of the
Zrythm trademarks
- to clarify proper usage of Zrythm trademarks by
third parties
- to prevent misuse of Zrythm trademarks that can confuse or mislead users with respect to Zrythm

Following are the guidelines for the proper use of
Zrythm trademarks by publishers and other third
parties. Any use of or reference to Zrythm trademarks
that is inconsistent with these guidelines, or other
unauthorized use of or reference to Zrythm
trademarks, or use of marks that are confusingly
similar to Zrythm trademarks, is prohibited and may
violate the trademark rights of Alexandros Theodotou.

Any use of Zrythm trademarks in a misleading and false
manner, such as untruthful advertising, is always
prohibited.

# Usage Guidelines
This Trademark Policy explicitly affirms your
nominative fair use rights under trademark law,
including to:
- Use the Zrythm wordmark in text to truthfully refer
to and/or link to unmodified programs, products,
services and technologies by Alexandros Theodotou.
- Use the Zrythm logo in visuals to truthfully refer
to and/or to link to the applicable unmodified
programs, products, services and technologies by
Alexandros Theodotou.
- Use Zrythm trademarks to make true factual
statements about Zrythm or communicate compatibility
with your product truthfully.

The following are explicitly forbidden:
- Use of the Zrythm wordmark as part of a company
name or logo, a product name or logo, or branding.
- Use of the Zrythm logo as part of a company logo or
organization logo or product logo or branding.
- Use of the Zrythm wordmark as part of an acronym.
- Use of Zrythm trademarks in any way that suggests
an affiliation with or endorsement by the Zrythm
project or community, if that is not the case.

All other uses of a Zrythm trademark require our
prior written permission. Contact
trademarks@zrythm.org for more information.

# Unaltered Software Distribution Policy
You may distribute unaltered copies of Zrythm that
include the Zrythm trademarks without express
permission from Alexandros Theodotou.

# Requirement of Written Permission for Modified Versions Including Trademarks
Zrythm is
[free software](http://www.gnu.org/philosophy/free-sw.html),
and its license allows you
to freely download, modify and redistribute the
source code. However, if you make any changes to
Zrythm, you may not redistribute that product using
any Zrythm trademark without Alexandros Theodotou’s
prior written consent. For example, you may not
distribute a modified form of Zrythm and continue to
call it Zrythm, or include the Zrythm logo. If you
wish to distribute a modified version of Zrythm that
includes the Zrythm trademarks please contact us with
your request at trademarks@zrythm.org.

# Newer Versions of this Policy
This policy may be revised from time to time. The
file `TRADEMARKS.md` in the source code releases will
always contain the current policy at the time of
each release.

==> zrythm-0.8.797.tar.xz: zrythm-0.8.797/TRADEMARKS.md <==
Trademark Policy
================

# Applicable Trademarks
The word "Zrythm" and the Zrythm logo are trademarks
of Alexandros Theodotou pending registration.

# Objective of this Policy
The objective of this trademark policy is:
- to encourage widespread use and adoption of the
Zrythm trademarks
- to clarify proper usage of Zrythm trademarks by
third parties
- to prevent misuse of Zrythm trademarks that can confuse or mislead users with respect to Zrythm

Following are the guidelines for the proper use of
Zrythm trademarks by publishers and other third
parties. Any use of or reference to Zrythm trademarks
that is inconsistent with these guidelines, or other
unauthorized use of or reference to Zrythm
trademarks, or use of marks that are confusingly
similar to Zrythm trademarks, is prohibited and may
violate the trademark rights of Alexandros Theodotou.

Any use of Zrythm trademarks in a misleading and false
manner, such as untruthful advertising, is always
prohibited.

# Usage Guidelines
This Trademark Policy explicitly affirms your
nominative fair use rights under trademark law,
including to:
- Use the Zrythm wordmark in text to truthfully refer
to and/or link to unmodified programs, products,
services and technologies by Alexandros Theodotou.
- Use the Zrythm logo in visuals to truthfully refer
to and/or to link to the applicable unmodified
programs, products, services and technologies by
Alexandros Theodotou.
- Use Zrythm trademarks to make true factual
statements about Zrythm or communicate compatibility
with your product truthfully.

The following are explicitly forbidden:
- Use of the Zrythm wordmark as part of a company
name or logo, a product name or logo, or branding.
- Use of the Zrythm logo as part of a company logo or
organization logo or product logo or branding.
- Use of the Zrythm wordmark as part of an acronym.
- Use of Zrythm trademarks in any way that suggests
an affiliation with or endorsement by the Zrythm
project or community, if that is not the case.

All other uses of a Zrythm trademark require our
prior written permission. Contact
trademarks@zrythm.org for more information.

# Software Distribution Policy
You may distribute unaltered copies of Zrythm that
include the Zrythm trademarks without express
permission from Alexandros Theodotou.

You may further distribute altered copies of Zrythm
that include the Zrythm trademarks, provided that
alterations solely serve the purposes of:
- porting Zrythm to a free system distribution
currently approved by the Free Software Foundation at
https://www.gnu.org/distros/free-distros.html, OR
- fixing a bug in Zrythm that has already been
acknowledged by Alexandros Theodotou or CVE
(https://cve.mitre.org/)

In any case, you may not add or remove
functionalities and you must preserve all messages
presented to users in the user interface and the
command line, including but not limited to:
- URLs pointing to official Zrythm web pages
- informational messages (popups, console output,
etc.)

You must also provide a link to the original source
code as published by Alexandros Theodotou at
https://www.zrythm.org/releases/.

# Requirement of Written Permission for Modified Versions Including Trademarks
Zrythm is
[free software](http://www.gnu.org/philosophy/free-sw.html),
and its license allows you
to freely download, modify and redistribute the
source code. However, if you make any changes to
Zrythm not explicitly allowed above, you may not
redistribute that product using any Zrythm trademark
without Alexandros Theodotou’s prior written
consent. For example, you may not distribute a
modified form of Zrythm and continue to call it
Zrythm, or include the Zrythm logo. If you wish to
distribute a modified version of Zrythm that
includes the Zrythm trademarks please contact us with
your request at trademarks@zrythm.org.

# Newer Versions of this Policy
This policy may be revised from time to time. The
file `TRADEMARKS.md` in the source code releases will
always contain the current policy at the time of
each release.
